@@ -636,6 +636,7 @@ def _download_single_file(
 def download_dir(
     dataset_id: str,
     commit: Optional[str] = None,
+    sub_dir: Optional[str] = None,
     cache_dir: Optional[Union[str, Path]] = None,
     local_dir: Optional[Union[str, Path]] = None,
     token: Optional[str] = None,
@@ -644,7 +645,9 @@ def download_dir(
 
     Args:
         id (str): The dataset id.
-
+        sub_dir (str): The sub directory to download. If not specified, the whole dataset will be downloaded.
+        cache_dir (str): The cache directory. If not provided, the default cache directory will be used.
+        local_dir (str): The local directory to save the file to. If not provided, the default cache directory will be used.
     Returns:
         str: The path to the downloaded directory.
     """
@@ -677,6 +680,9 @@ def download_dir(
             sub_path = file_json.get("SubPath")
             if sub_path is not None:
                 filepath_in_dataset = os.path.join(sub_path, filepath_in_dataset)
+            # skip file if sub_dir is specified and filepath_in_dataset not in sub_dir
+            if sub_dir is not None and os.path.commonpath([sub_dir, filepath_in_dataset]) != sub_dir:
+                continue
             key = path_to_key[filepath_in_dataset]
             mw_cached_root_dir = os.environ.get("MW_CACHED_ROOT_DIR", "/var/mw")
             sock_path = os.path.join(mw_cached_root_dir, "cached.sock")
